@@ -2,11 +2,16 @@ use strict;
 use warnings;
 
 package Test::CleanNamespaces;
-our $VERSION = '0.02';
-
+BEGIN {
+  $Test::CleanNamespaces::AUTHORITY = 'cpan:FLORA';
+}
+{
+  $Test::CleanNamespaces::VERSION = '0.03';
+}
 # ABSTRACT: Check for uncleaned imports
 
 use Class::MOP;
+use Module::Runtime 'use_module';
 use Sub::Name 'subname';
 use Test::Builder;
 use File::Find::Rule;
@@ -38,13 +43,13 @@ sub build_namespaces_clean {
         local $@;
 
         for my $ns (@namespaces) {
-            unless (eval { Class::MOP::load_class($ns); 1 }) {
+            unless (eval { use_module($ns); 1 }) {
                 $class->builder->skip("failed to load ${ns}: $@");
                 next;
             }
 
             my $meta = Class::MOP::class_of($ns) || Class::MOP::Class->initialize($ns);
-            my %methods = map { ($_ => 1) } keys %{ $meta->get_method_map || {} };
+            my %methods = map { ($_ => 1) } $meta->get_method_list;
             my @symbols = keys %{ $meta->get_all_package_symbols('CODE') || {} };
             my @imports = grep { !$methods{$_} } @symbols;
 
@@ -92,14 +97,12 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Test::CleanNamespaces - Check for uncleaned imports
 
-=head1 VERSION
-
-version 0.02
-
 =head1 SYNOPSIS
 
     use strict;
@@ -143,8 +146,6 @@ what you want to override if you're subclassing this module..
 
 Returns a coderef that will be exported as C<namespaces_clean>.
 
-
-
 =head2 build_all_namespaces_clean
 
     my $coderef = Test::CleanNamespaces->build_namespaces_clean;
@@ -152,8 +153,6 @@ Returns a coderef that will be exported as C<namespaces_clean>.
 Returns a coderef that will be exported as C<all_namespaces_clean>. It will use
 the C<find_modules> method to get the list of modules to check.
 
-
-
 =head2 find_modules
 
     my @modules = Test::CleanNamespaces->find_modules;
@@ -161,27 +160,21 @@ the C<find_modules> method to get the list of modules to check.
 Returns a list of modules in the current distribution. It'll search in
 C<blib/>, if it exists. C<lib/> will be searched otherwise.
 
-
-
 =head2 builder
 
     my $builder = Test::CleanNamespaces->builder;
 
 Returns the C<Test::Builder> used by the test functions.
 
-
-
 =head1 AUTHOR
 
-  Florian Ragwitz <rafl@debian.org>
+Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Florian Ragwitz.
+This software is copyright (c) 2013 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
-
+=cut
